mindroot.coreplugins.events package - MindRoot 9.10.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# mindroot.coreplugins.events package

## Submodules

## mindroot.coreplugins.events.mod module

## mindroot.coreplugins.events.router module

async mindroot.coreplugins.events.router.create_sse_client(url: str, access_token: str, queue: Queue, conv_id: str)

  Creates internal SSE client that forwards to queue with conversation ID

async mindroot.coreplugins.events.router.multiplexed_events(request: Request, conversation_ids: List[str] = Query(None))

## Module contents